@@ -799,6 +799,26 @@ class Agent(Insight, Channel, Catalog, Dataset):
 
         return response.json()
 
+    def get_feeds_slugs(self):
+        url = self._base_url_ch+"/channels?agentId="+self._agentId
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {"Authorization": "Bearer" + " " + self._token}
+        response = s.get(url=url, headers=headers)
+        response.raise_for_status()
+        feeds = response.json()
+
+        slugs = []
+
+        for feed in feeds:
+            slugs.append(feed["slug"])
+
+        return slugs
+
     def get_card_slug_from_feed(self, feed_slug):
 
         channel_id = self.get_channel(feed_slug)["id"]
