@@ -7,7 +7,6 @@ import numpy as np
 import logging
 from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
-import re
 from datetime import datetime
 
 _LOG_FORMAT = "[%(filename)s:%(lineno)s - %(funcName)20s() ] - %(asctime)s --> %(message)s"
@@ -120,7 +119,7 @@ class Insight:
                             if replace_elem_.sort() == elem.sort():
                                 replace_elem = [str(n).replace(agent_source._domain, self._domain) for n in replace_elem_]
                             else:
-                                replace_elem = replace_elem
+                                replace_elem = replace_elem_
                             insights_source.loc[Ind, name_elem] = replace_elem
 
                 if type(elem) == dict:
