@@ -117,7 +117,25 @@ class Insight_Definition:
     def edit_widget(self, widget_id, widget_type: str, query_ids:list, field_codes:dict, values:dict={}, texts:dict={}, charts:list=[]):
 
         url = self.smart_insight_url+"/definitions/"+self.definition_id+"/widgets/"+widget_id
-        columns = self.get_columns(query_ids)
+        columns = []
+        for query in query_ids:
+            if query.startswith("qcomp"):
+
+                qc = self.get_component(query)
+                url_preview = self.smart_insight_url + "/composed_queries/" + qc["settings"]["qc"] + "/preview?limit=100&agentId=" + self.agent_id
+                r = self.__make_post_request(url_preview, {})
+                cols = r.json()["schema"]
+                for col in cols:
+                    if(query not in ((str)(col["id"]))):
+                        col["id"] = query + "-" +col["id"]
+                    columns.append(col)
+                #cols = self.get_columns(query_ids)
+            else:
+                cols = self.get_columns(query_ids)
+                for col in cols:
+                    columns.append(col)
+
+        print(columns)
 
         settings = {}
         for field in field_codes.keys():
@@ -137,6 +155,8 @@ class Insight_Definition:
         for key in values.keys():
             settings[key + "_id"] = values[key]
 
+        print(settings)
+
         body = {
             "id" : widget_id,
             "type": "widget",
