@@ -21,7 +21,10 @@ def read_gsheet(spreadsheetId, credentials = None, sheet = None):
 
     if credentials is None:
 
-        post_url = "https://api.askdata.com/smartnotebook/readGsheet"
+        #post_url = "https://api.askdata.com/smartnotebook/readGsheet"
+        
+        post_url = 'https://smartnotebook.askdata.com/readGsheet'
+        
         body = {
             "spreadsheetId": spreadsheetId,
             "sheet": sheet
