@@ -3,12 +3,20 @@ from requests.adapters import HTTPAdapter
 from urllib3.util.retry import Retry
 import logging
 import requests
+import os
+import yaml
 
 pd.set_option('display.max_columns', None)
 pd.set_option('display.width', 200)
 pd.set_option('display.max_rows', 10)
 
 
+root_dir = os.path.abspath(os.path.dirname(__file__))
+yaml_path = os.path.join(root_dir, '../askdata/askdata_config/base_url.yaml')
+with open(yaml_path, 'r') as file:
+    url_list = yaml.load(file, Loader=yaml.FullLoader)
+
+
 def search_data(sentence, language="en", show_header=False, dataset_score_dict=None, boost_columns=False,
                 boost_name_score=False, use_domains=True, store_df=True):
     if language != "en" and language != "it":
@@ -36,7 +44,7 @@ def search_data(sentence, language="en", show_header=False, dataset_score_dict=N
         retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
         s.mount('https://', HTTPAdapter(max_retries=retries))
 
-        url = "https://api-dev.askdata.com/opendata/spacy"
+        url = url_list['BASE_URL_OPENDATA_DEV'] + "/spacy"
 
         r = s.post(url=url, headers=headers, json=data)
         r.raise_for_status()
