@@ -160,13 +160,16 @@ class Condition:
             operator = change_operator(operator)
         else:
             operator = None
-        field_with_agg = self.field.column
-        if self.field.aggregation is not None:
-            if isinstance(self.field.aggregation, SQLFunction) or isinstance(self.field.aggregation,
-                                                                             TimeDimensionGranularity):
-                field_with_agg = self.field.aggregation.name + " ( " + field_with_agg + " )"
-            else:
-                field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
+        if self.field.column is not None:
+            field_with_agg = self.field.column
+            if self.field.aggregation is not None:
+                if isinstance(self.field.aggregation, SQLFunction) or isinstance(self.field.aggregation,
+                                                                                 TimeDimensionGranularity):
+                    field_with_agg = self.field.aggregation.name + " ( " + field_with_agg + " )"
+                else:
+                    field_with_agg = self.field.aggregation + " ( " + field_with_agg + " )"
+        elif self.field.complexExpression is not None:
+            field_with_agg = self.field.complexExpression
 
         if formatted_value is not None and self.direction is None:
             where_condition = (
